@@ -94,8 +94,8 @@ class Job(object):
     """
 
     __slots__ = ('_f', 'args', 'jobid', 'kwlist', 'cleanup', 'ret', 'exception',
-                 'environment', 'replace_env', 'working_dir', 'num_slots',
-                 'mem_free', 'white_list', 'path', 'uniq_id', 'name', 'queue')
+                 'num_slots', 'mem_free', 'white_list', 'path',
+                 'uniq_id', 'name', 'queue', 'environment', 'working_dir')
 
     def __init__(self, f, args, kwlist=None, cleanup=True, mem_free="1G",
                  name='gridmap_job', num_slots=1, queue=DEFAULT_QUEUE):
@@ -129,14 +129,23 @@ class Job(object):
         self.kwlist = kwlist if kwlist is not None else {}
         self.cleanup = cleanup
         self.ret = None
-        self.environment = None
-        self.replace_env = False
-        self.working_dir = os.getcwd()
         self.num_slots = num_slots
         self.mem_free = mem_free
         self.white_list = []
         self.name = name.replace(' ', '_')
         self.queue = queue
+        # fetch env vars from shell
+        env = {env_var: value for env_var, value in os.environ.items()}
+        # Work around for bug in drmaa-python
+        if sys.version_info >= (3, 0):
+            for env_var, value in os.environ.items():
+                if isinstance(env_var, str):
+                    env_var = env_var.encode('utf-8')
+                if isinstance(value, str):
+                    value = value.encode('utf-8')
+                env[env_var] = value
+        self.environment = env
+        self.working_dir = clean_path(os.getcwd())
 
     @property
     def function(self):
@@ -278,31 +287,21 @@ def _append_job_to_session(session, job, uniq_id, job_num, temp_dir='/scratch/',
 
     jt = session.createJobTemplate()
 
-    # fetch env vars from shell
-    shell_env = os.environ
-
-    if job.environment and job.replace_env:
-        # only consider defined env vars
-        jt.jobEnvironment = job.environment
-
-    elif job.environment and not job.replace_env:
-        # replace env var from shell with defined env vars
-        env = shell_env
-        env.update(job.environment)
-        jt.jobEnvironment = env
-
-    else:
-        # only consider env vars from shell
-        jt.jobEnvironment = shell_env
+    jt.jobEnvironment = job.environment
 
     # Run module using python -m to avoid ImportErrors when unpickling jobs
     jt.remoteCommand =  sys.executable
     jt.args = ['-m', 'gridmap.runner', '{0}'.format(uniq_id),
                '{0}'.format(job_num), job.path, temp_dir, gethostname()]
     jt.nativeSpecification = job.native_specification
+    jt.workingDirectory = job.working_dir
     jt.outputPath = ":" + temp_dir
     jt.errorPath = ":" + temp_dir
 
+    # Create temp directory if necessary
+    if not os.path.exists(temp_dir):
+        os.makedirs(temp_dir)
+
     jobid = session.runJob(jt)
 
     # set job fields that depend on the jobid assigned by grid engine
@@ -428,6 +427,9 @@ def _collect_jobs(sid, jobids, joblist, redis_server, uniq_id,
                       file=sys.stderr)
                 print("stdout:", log_stdout_fn, file=sys.stderr)
                 print("stderr:", log_stderr_fn, file=sys.stderr)
+                print("Environment variables: {0}".format(job.environment),
+                      file=sys.stderr)
+                print("Working directory: {0}".format(job.working_dir))
                 # See if we have extended job info, and print it if we do
                 job_info = job_info_list[ix]
                 if not isinstance(job_info, Exception):
@@ -510,12 +512,14 @@ def process_jobs(jobs, temp_dir='/scratch/', wait=True, white_list=None,
                                              stdout=null_file,
                                              stdin=subprocess.PIPE,
                                              stderr=null_file)
-            redis_process.stdin.write('''daemonize yes
-                                         pidfile {0}
-                                         port {1}
-                                      '''.format(os.path.join(temp_dir,
-                                                              'redis{0}.pid'.format(REDIS_PORT)),
-                                                 REDIS_PORT))
+            config = '''daemonize yes
+                        pidfile {0}
+                        port {1}
+                     '''.format(os.path.join(temp_dir,
+                                             'redis{0}.pid'.format(REDIS_PORT)),
+                                REDIS_PORT)
+            config = config.encode('utf-8')
+            redis_process.stdin.write(config)
             redis_process.stdin.close()
             # Wait for things to get started
             sleep(5)
